@@ -4,6 +4,7 @@
 #'
 #' @param x lmerModLmerTest object.
 #' @param CI Bootsrapped confidence interval bounds (slow). Set to NULL turn off their computation.
+#' @param effsize_rules Grid for effect size interpretation. See \link[=interpret_d]{interpret_d}.
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @return output
@@ -24,7 +25,7 @@
 #' @importFrom stringr str_squish
 #' @import dplyr
 #' @export
-analyze.lmerModLmerTest <- function(x, CI=95, ...) {
+analyze.lmerModLmerTest <- function(x, CI=95, effsize_rules="cohen1988", ...) {
 
 
   # Processing
@@ -40,7 +41,8 @@ analyze.lmerModLmerTest <- function(x, CI=95, ...) {
 
 
   # TODO: Bootstrapped p values
-  # boot.out = lme4::bootMer(fit, lme4::fixef, nsim=1000) #nsim determines p-value decimal places
+  # nsim determines p-value decimal places
+  # boot.out = lme4::bootMer(fit, lme4::fixef, nsim=1000)
   # p = rbind(
   #   (1-apply(boot.out$t<0, 2, mean))*2,
   #   (1-apply(boot.out$t>0, 2, mean))*2)
@@ -63,7 +65,7 @@ analyze.lmerModLmerTest <- function(x, CI=95, ...) {
   stdz <- as.data.frame(MuMIn::std.coef(fit, partial.sd = FALSE))
   fitsum$Coef.std <- stdz$Estimate
   fitsum$SE.std <- stdz$`Std. Error`
-  fitsum$Effect_Size <- interpret_d(fitsum$Coef.std)
+  fitsum$Effect_Size <- interpret_d(fitsum$Coef.std, rules = effsize_rules)
 
   fitsum <- dplyr::select_(
     fitsum, "Variable", "Coef", "SE", "t", "df", "Coef.std", "SE.std",
